//! -*- Mode: C++; -*-
/**********************************************************************

	--- Qt Architect generated file ---

	File: changetablename.h
	Last generated: Sun Oct 10 04:59:05 1999

 *********************************************************************/

#ifndef CChangeTableName_included
#define CChangeTableName_included

#include "changetablenamedata.h"
//#include "mysqlw.h"

#include "stringlist.h"
#include "smart_pointer.h"

class CMySql;

class CChangeTableName : public CChangeTableNameData
{
    Q_OBJECT

public:
    CChangeTableName(smart_pointer<CMySql>& _sql_server,QWidget* parent = NULL,const char* name = NULL);
    virtual ~CChangeTableName();
protected slots:
    virtual void change_name();
    virtual void name_changed(const QString&);
    virtual void db_selected(int);
    virtual void table_selected(int);
protected:
    smart_pointer<CMySql> sql_server;
    stringlist db_list;
    stringlist table_list;
};
#endif // CChangeTableName_included

